Changelog
=========

Version 0.0.5, 2023-03-02
-----------------------

- Fixed issues with passing include directories over CLI.

Version 0.0.4, 2023-02-28
-----------------------

- Fixed import error due to IDE autocompletion

Version 0.0.3, 2023-02-27
-----------------------

- Added Option to provide additional include directories over CLI.
- Added Option to provide additional include directories to IncludeResolver.
- Added possibility to merge values in nested dictionaries on include.
